#ifndef KYLIN_SYSTEM_SYSTEM_INFORMATION_
#define KYLIN_SYSTEM_SYSTEM_INFORMATION_

#include <QString>

namespace kdk
{
namespace kabase
{

class SystemInformation
{
public:
    SystemInformation();
    ~SystemInformation();

    /**
     * @brief 根据 lsb-release 文件的 key 值 获取信息
     *
     * @param key 键值
     *
     * @return 获取到的信息 , 为空时可能确实为空也可能失败
     */
    QString getLsbReleaseInformation(QString key);

    /**
     * @brief 根据 os-release 文件的 key 值 获取信息
     *
     * @param key 键值
     *
     * @return 获取到的信息 , 为空时可能确实为空也可能失败
     */
    QString getOsReleaseInformation(QString key);

    /**
     * @brief 获取 PROJECT_CODENAME 字段的值
     *
     * @param 无
     *
     * @retval 空 失败
     * @retval 非空 获取到的值
     */
    QString getProjectCodeName(void);

    /**
     * @brief 获取 CPU 型号
     *
     * @param 无
     *
     * @retval 空 失败
     * @retval 非空 获取到的值
     */
    QString getCpuModelName(void);

    /**
     * @brief 获取硬件平台信息
     *
     * @param 无
     *
     * @retval 空 失败
     * @retval 非空 获取到的值
     */
    QString getHdPlatform(void);
};

} /* namespace kabase */
} /* namespace kdk */

#endif